@@ -24,20 +24,24 @@
 #' @examples
 #' library(survival)
 #' library(survex)
-#' cph <- survival::coxph(survival::Surv(time, status) ~ ., data = veteran,
-#'                        model = TRUE, x = TRUE, y = TRUE)
+#' cph <- survival::coxph(survival::Surv(time, status) ~ .,
+#'     data = veteran,
+#'     model = TRUE, x = TRUE, y = TRUE
+#' )
 #' surv_model_info(cph)
 #'
 #' \donttest{
 #' library(ranger)
-#' rsf_ranger <- ranger::ranger(survival::Surv(time, status) ~ ., data = veteran,
-#'  num.trees = 50, mtry = 3, max.depth = 5)
+#' rsf_ranger <- ranger::ranger(survival::Surv(time, status) ~ .,
+#'     data = veteran,
+#'     num.trees = 50, mtry = 3, max.depth = 5
+#' )
 #' surv_model_info(rsf_ranger)
 #' }
 #'
-surv_model_info <- function(model, ...)
+surv_model_info <- function(model, ...) {
     UseMethod("surv_model_info")
-
+}
 
 #' @rdname surv_model_info
 #' @export
@@ -98,7 +102,6 @@ surv_model_info.cph <- function(model, ...) {
     model_info
 }
 
-
 #' @rdname surv_model_info
 #' @export
 surv_model_info.LearnerSurv <- function(model, ...) {
@@ -110,14 +113,34 @@ surv_model_info.LearnerSurv <- function(model, ...) {
     model_info
 }
 
+#' @rdname surv_model_info
+#' @export
+surv_model_info.sksurv <- function(model, ...) {
+    type <- "survival"
+    package <- "scikit-survival"
+    ver <- get_pkg_ver_safe(package)
+    model_info <- list(package = package, ver = ver, type = type)
+    class(model_info) <- "model_info"
+    model_info
+}
 
+#' @rdname surv_model_info
+#' @export
+surv_model_info.flexsurvreg <- function(model, ...) {
+    type <- "survival"
+    package <- "flexsurv"
+    ver <- get_pkg_ver_safe(package)
+    model_info <- list(package = package, ver = ver, type = type)
+    class(model_info) <- "model_info"
+    model_info
+}
 
 #' @rdname surv_model_info
 #' @export
 surv_model_info.default <- function(model, ...) {
     type <- "survival"
-    package <- paste("Model of class:", class(model), "package unrecognized")
-    ver <- "Unknown"
+    package <- paste("unrecognized ,", "model of class:", class(model))
+    ver <- "unknown"
     model_info <- list(package = package, ver = ver, type = type)
     class(model_info) <- "model_info"
     model_info
@@ -126,7 +149,7 @@ surv_model_info.default <- function(model, ...) {
 get_pkg_ver_safe <- function(package) {
     ver <- try(as.character(utils::packageVersion(package)), silent = TRUE)
     if (inherits(ver, "try-error")) {
-        ver <- "Unknown"
+        ver <- "unknown"
     }
     ver
 }
